/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.monitoring;

import java.util.Map;

import org.apache.hbase.thirdparty.com.google.common.collect.ImmutableMap;

public interface HistogramDistribution {
  public long getMin();

  public long getMax();

  public long getCount();

  public String getHistoName();

  public Map<String, Long> getRangeDistributionMap();

  default ImmutableMap<String, Long> getPercentileDistributionMap() {
    throw new UnsupportedOperationException(
      "Percentile Histogram Distribution is not " + "supported!!");
  }

  default ImmutableMap<String, String> getTags() {
    return ImmutableMap.of();
  }
}
